@@ -8,7 +8,7 @@
 #   This file is a part of the Debian language-env package.
 #   Language Support File for Japanese
 #
-# Copyright (C) 1998-2002 Tomohiro KUBOTA
+# Copyright (C) 1998-2003 Tomohiro KUBOTA
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,40 +28,55 @@
 # This is needed to check Canna and Wnn.
 use Socket;
 
+# This is needed to support UTF-8.
+use Text::Iconv;
+
 # ---------------------------------------------------
 # isNC()
 # ---------------------------------------------------
 sub isNC($$$)
 {
-	my ($KANJI, $TTY, $TERM, $DISPLAY, $THIS, $OPT, $OPT_N, $a);
+	my ($KANJI, $TTY, $TERM, $DISPLAY, $THIS, $OPT, $OPT_N, $a, $CHARMAP);
 	$TTY = `/usr/bin/tty`;
 	$TERM = $ENV{TERM};
 	$DISPLAY = $ENV{DISPLAY};
 	$THIS = $_[0];
 	$OPT = $_[1];
 	$OPT_N = $_[2];
+	$UTF8 = 0;
+	$CHARMAP = `/usr/bin/locale charmap`; chomp($CHARMAP);
+	$euc2utf8 = Text::Iconv->new("EUC-JP", "UTF-8");
+
 	if ($DISPLAY ne '' && $ENV{WINDOWID} ne '' && &executable("xprop")) {
 		$a = system("/usr/bin/X11/xprop -id $ENV{WINDOWID} &> /dev/null");
 		if ($a == 0) {$WM = `/usr/bin/X11/xprop -id $ENV{WINDOWID}`;}
 		else {$WM = ""; $DISPLAY = "";}
 	}
 	
-	if ($TERM eq 'kon' || $TERM eq 'jfbterm') {
-		$KANJI=1;
-	} elsif ($TERM eq 'kterm') {
+	if ($TERM eq 'kon' || $TERM eq 'kterm') {
 		$KANJI=1;
+	} elsif ($TERM eq 'jfbterm' || $TERM eq 'mlterm' || $TERM eq 'xterm') {
+		$KANJI=1000;
 	} elsif ($DISPLAY ne '' && $TERM eq 'rxvt' && $WM =~ /krxvt/) {
 		$KANJI=1;
 	} elsif ($DISPLAY ne '' && &executable("kterm") && !$OPT_N) {
 		exec("kterm -km euc -e $THIS -N -C $OPT");
 	} elsif ($DISPLAY ne '' && &executable("krxvt") && !$OPT_N) {
 		exec("krxvt -km euc -e $THIS -N -C $OPT");
+	} elsif ($DISPLAY ne '' && &executable("mlterm") && !$OPT_N) {
+		exec("mlterm -E EUCJP -e $THIS -N -C $OPT");
 	} else {
-		print STDERR &sourceset2displayset("ʸɤޤ\n");
+		$a = "ʸɤޤ\n";
+		if ($CHARMAP eq 'UTF-8') {
+			print STDERR &sourceset2utf8($a);
+		} else {
+			print STDERR &sourceset2eucjp($a);
+		}
 		print STDERR "UE NO BUNSYOU (KANJI) GA YOMEMASUKA? [y/N] ";
 		$a = <>;
 		if ($a =~ /y|Y/) {
-			$KANJI=1;
+			if ($CHARMAP eq 'UTF-8') {$KANJI=2;}
+			else {$KANJI=1;}
 		} elsif ($TTY =~ m!/dev/tty[0-9]+! && &executable("kon") 
 		  && !$OPT_N) {
 			print STDERR "\"KON\" WO JIKKOU SHIMASUKA? [Y/n] ";
@@ -78,7 +93,12 @@ sub isNC($$$)
 			$KANJI=0;
 		}
 	}
-	$KANJI;
+	if ($KANJI == 1000) {
+		if ($CHARMAP eq 'UTF-8') {$KANJI=2;}
+		elsif ($CHARMAP eq 'EUC-JP') {$KANJI=1;}
+		else {$KANJI=0;}
+	}
+	$KANJIMODE = $KANJI;
 }
 
 sub executable($)
@@ -98,17 +118,23 @@ sub initialize()
 	&check_im("Canna", 5680, "/tmp/.iroha_unix/IROHA");
 	&check_im("Wnn", 22273, "");
 	&check_im("SKK", 1178, "");
+	&check_im("Anthy", 0, "");
+	&check_im("PRIME", 0, "");
 
 	# ---------- select default input method ----------
 	$m = 0;
-	foreach $i ("Canna", "Wnn", "SKK") {
+	foreach $i ("Canna", "Wnn", "SKK", "Anthy", "PRIME") {
 		$m += $Sub::IM_EXIST{$i};
 		if ($Sub::IM_EXIST{$i}) {$def = $i;}
 	}
 	if ($m == 1) {
 		$Sub::IM_DEFAULT = $def;
 	} else {
-		if ($Sub::IM_EXIST{"SKK"}) {
+		if ($Sub::IM_EXIST{"PRIME"}) {
+			$d = 5;
+		} elsif ($Sub::IM_EXIST{"Anthy"}) {
+			$d = 4;
+		} elsif ($Sub::IM_EXIST{"SKK"}) {
 			$d = 3;
 		} elsif ($Sub::IM_EXIST{"Wnn"}) {
 			$d = 2;
@@ -119,13 +145,15 @@ sub initialize()
 		}
 		$dd = &Sub::select(
 			"KANJI HENKAN NIHA DORE WO TSUKAI MASUKA ".
-			"1=Canna 2=Wnn 3=SKK 4=none ",
+			"1=Canna 2=Wnn 3=SKK 4=Anthy 5=PRIME 6=none ",
 			"ѴˤϤɤȤޤ ".
-			"1=Canna 2=Wnn 3=SKK 4=ʤ ", 4, $d);
+			"1=Canna 2=Wnn 3=SKK 4=Anthy 5=PRIME 6=ʤ ", 6, $d);
 		if ($dd == 1) {$Sub::IM_DEFAULT = "Canna";}
 		if ($dd == 2) {$Sub::IM_DEFAULT = "Wnn";}
 		if ($dd == 3) {$Sub::IM_DEFAULT = "SKK";}
-		if ($dd == 4) {$Sub::IM_DEFAULT = "";}
+		if ($dd == 4) {$Sub::IM_DEFAULT = "Anthy";}
+		if ($dd == 5) {$Sub::IM_DEFAULT = "PRIME";}
+		if ($dd == 6) {$Sub::IM_DEFAULT = "";}
 	}
 	$Sub::EXTENDED =
 	    &Sub::yesno("NIHONGO NIHA KANKEINO NAI " .
@@ -152,6 +180,16 @@ sub initialize()
 			}
 		}
 		system("/usr/bin/touch ~/.skk-jisyo");
+	} elsif ($Sub::IM_DEFAULT eq "Anthy") {
+		if (!$IM_EXIST{"Anthy"}) {
+			&Sub::addlist("anthy");
+			&Sub::addlist("uim-xim");
+		}
+	} elsif ($Sub::IM_DEFAULT eq "PRIME") {
+		if (!$IM_EXIST{"PRIME"}) {
+			&Sub::addlist("prime");
+			&Sub::addlist("uim-xim");
+		}
 	}
 
 	# ---------- add required packages ----------
@@ -163,26 +201,29 @@ sub initialize()
 #	&Sub::addlist("dpkg-doc-ja");
 	if (&Sub::isinstalled("less")) {&Sub::addlist("jless");}
 #	if (&Sub::isinstalled("groff")) {&Sub::addlist("jgroff");}
-	if (&Sub::isinstalled("fvwm2")) {&Sub::addlist("fvwm2-ja");}
+#	if (&Sub::isinstalled("fvwm2")) {&Sub::addlist("fvwm2-ja");}
 #	if (&Sub::isinstalled("fvwm95")) {&Sub::addlist("fvwm95-ja");}
 #	if (&Sub::isinstalled("afterstep")) {&Sub::addlist("afterstep-i18n");}
 	if (&Sub::isinstalled("tcsh")) {&Sub::addlist("tcsh-kanji");}
 #	if (&Sub::isinstalled("dvi2tty")) {&Sub::addlist("dvi2tty-ja");}
-	if (&Sub::isinstalled("mutt")) {&Sub::addlist("mutt-ja");}
+#	if (&Sub::isinstalled("mutt")) {&Sub::addlist("mutt-ja");}
 	if (&Sub::isinstalled("slrn")) {&Sub::addlist("slrn-ja");}
 #	if (&Sub::isinstalled("tgif")) {&Sub::addlist("tgif-ja");}
 	if (&Sub::isinstalled("xjed")) {&Sub::addlist("xjed-ja");}
 	if (&Sub::isinstalled("xterm")) {&Sub::addlist("kterm");}
-	if (&Sub::isinstalled("rxvt")) {&Sub::addlist("rxvt-ml");}
+	if (&Sub::isinstalled("xterm")) {
+		&Sub::addlist("kterm");
+		&Sub::addlist("xutils");
+	}
+	if (&Sub::isinstalled("rxvt")) {&Sub::addlist("rxvt-beta");}
 	if (&Sub::isinstalled("nethack")) {&Sub::addlist("jnethack");}
 	if (&Sub::isinstalled("doc-debian")) {&Sub::addlist("doc-debian-ja");}
-	if (&Sub::isinstalled("doc-linux")) {&Sub::addlist("doc-linux-ja");}
-	if (&Sub::isinstalled("doc-debian-html")) {
-		&Sub::addlist("doc-debian-html-ja");
-	}
-
+	if (&Sub::isinstalled("apt-howto")) {&Sub::addlist("apt-howto-ja");}
 	if (&Sub::isinstalled("doc-linux-text")) {
-		&Sub::addlist("doc-linux-text-ja");
+		&Sub::addlist("doc-linux-ja-text");
+	}
+	if (&Sub::isinstalled("doc-linux-html")) {
+		&Sub::addlist("doc-linux-ja-html");
 	}
 	if (&Sub::isinstalled("vim")) {
 		&Sub::addlist("jvim-canna");
@@ -220,6 +261,32 @@ sub check_im($$$)
 	$im = $_[0];
 	$port = $_[1];
 	$unix_tmp = $_[2];
+
+	if($im eq "PRIME") {
+		&Sub::disp("PRIME GA UGOITE ", "PRIME ư");
+		if(-f "/usr/bin/prime") {
+			&Sub::disp("IMASU.\n","ޤ\n");
+			$Sub::IM_EXIST{$im} = 1;
+		} else {
+			&Sub::disp("IMASEN.\n","ޤ\n");
+			$Sub::IM_EXIST{$im} = 0;
+		}
+		$Sub::IM_HOST{$im} = "";
+		return;
+	}
+
+	if($im eq "Anthy") {
+		&Sub::disp("Anthy GA UGOITE ", "Anthy ư");
+		if(-f "/usr/bin/anthy-agent") {
+			&Sub::disp("IMASU.\n","ޤ\n");
+			$Sub::IM_EXIST{$im} = 1;
+		} else {
+			&Sub::disp("IMASEN.\n","ޤ\n");
+			$Sub::IM_EXIST{$im} = 0;
+		}
+		$Sub::IM_HOST{$im} = "";
+		return;
+	}
 	
 	&Sub::disp("$im server GA UGOITE ", "$im Сư");
 	if ($unix_tmp ne "" && socket(S,PF_UNIX,SOCK_STREAM,0) &&
@@ -263,6 +330,7 @@ sub sourceset2displayset ($)
 {
 	my ($a, $b, $r);
 	$a = $_[0];
+	if ($KANJIMODE == 2) {return &sourceset2utf8($a);}
 	$r = "";
 	while (length($a) != 0) {
 		$a =~ /^([\0-\177]*)(.*)/s;
@@ -279,6 +347,22 @@ sub sourceset2displayset ($)
 	$r;
 }
 
+sub sourceset2eucjp($)
+{
+	my ($a);
+	$a = $_[0];
+	$a;
+}
+
+sub sourceset2utf8($)
+{
+	my ($a, $r);
+	$a = $_[0];
+	$r = $euc2utf8->convert($a);
+	$r;
+}
+
+
 # ---------------------------------------------------
 # analcode()
 # ---------------------------------------------------
